Learn R Programming

forensim (version 3.1)

LR: Likelihood ratio for DNA evidence interpretation (2): a sophistacted version of function LR()

Description

LR Allows the calculation of likelihood ratios for a piece of DNA evidence, for any number of replicates, any number of contributors, and when drop-in and drop-out are possible.

Usage

LR(Repliste, Tp, Td, Vp, Vd, xp, xd, theta, prDHet, prDHom, prC, freq)

Arguments

Repliste
list of the vectors of alleles present at a given locus for any number of replicates. If there are two replicates, showing alleles 12,13, and 14 respectively, then Repliste should be given as list(c(12,13),14). If a replicate is empty, set to
Tp
vector of genotypes for the known contributors under Hp. Genotype 12/17 should be given as a vector c(12,17) and genotypes 12/17,14/16, should be given as a unique vector: c(12,17,14,16).
Td
vector of genotypes for the known contributors under Hd. Should be in the same format as Tp. If there are no known contributors under Hd, then set Td to NULL.
Vp
vector of genotypes for the known non-contributors (see References section) under Hp. See Tp for format.)
Vd
vector of genotypes for the known non-contributors (see References section) under Hd. Should be in the same format than Vp, if empty, set to NULL.
xp
Number of unknown individuals under Hd. Set to 0 if there are no unknown contributors.
xd
Number of unknown individuals under Hd. Set to 0 if there are no unknown contributors.
theta
thete correction, value must be taken in [0,1)
prDHet
probability of dropout for heterozygotes. It is possible to assign different values per contributor. In this case, prDHet must be a vector, of length the number of contributors in T + x, and the probabilities must be given in this order. if t
prDHom
probability of dropout for homozygotes. See description ofr argument PrDHom.
prC
probability of drop-in applied per locus
freq
vector of the corresponding allele frequencies of the analysed locus in the target population

References

Gill, P.; Kirkham, A. & Curran, J. LoComatioN: A software tool for the analysis of low copy number DNA profiles Forensic Science International, 2007, 166(2-3), 128-138 Curran, J. M.; Gill, P. & Bill, M. R. Interpretation of repeat measurement DNA evidence allowing for multiple contributors and population substructure Forensic Science International, 2005, 148, 47-53

See Also

LRmixTK

Examples

Run this code
#load allele frequencies
library(forensim)
data(ngm)
#create vector of allele frequencies
d10<-ngm$tab$D10
# heterozygote dropout probability (resp. homozygote) is set to 0.2 for all
# contributors (0.04 for homozygotes) 
LR(Repliste=list(c(12,13,14)),Tp=c(12,13),Td=0,Vp=0,Vd=0,xd=2,xp=1,theta=0,prDHet=c(0.2,0.2),
prDHom=c(0.04,0.04),prC=0,freq=d10)

Run the code above in your browser using DataLab