Learn R Programming

forensim (version 3.1)

likEvid: Likelihood of DNA evidence conditioned on a given hypothesis

Description

likEvid allows the calculation of likelihood for a piece of DNA evidence, for any number of replicates, any number of contributors, and when drop-in and drop-out are possible.

Usage

likEvid(Repliste, T, V, x, theta, prDHet, prDHom, prC, freq)

Arguments

Repliste
list of the vectors of alleles present at a given locus for any number of replicates. If there are two replicates, showing alleles 12,13, and 14 respectively, then Repliste should be given as list(c(12,13),14). If a replicate is empty, set to
T
vector of genotypes for the known contributors under Hp. Genotype 12/17 should be given as a vector c(12,17) and genotypes 12/17,14/16, should be given as a unique vector: c(12,17,14,16). If T is empty, set to NULL.
V
vector of genotypes for the known non-contributors (see References section) under Hp. See T for format.)
x
Number of unknown individuals under H. Set to 0 if there are no unknown contributors.
theta
thete correction, value must be taken in [0,1)
prDHet
probability of dropout for heterozygotes. It is possible to assign different values per contributor. In this case, prDHet must be a vector, of length the number of contributors in T + x, and the probabilities must be given in this order. if t
prDHom
probability of dropout for homozygotes. See description ofr argument PrDHom.
prC
probability of drop-in applied per locus
freq
vector of the corresponding allele frequencies of the analysed locus in the target population

References

Gill, P.; Kirkham, A. & Curran, J. LoComatioN: A software tool for the analysis of low copy number DNA profiles Forensic Science International, 2007, 166(2-3), 128-138 Curran, J. M.; Gill, P. & Bill, M. R. Interpretation of repeat measurement DNA evidence allowing for multiple contributors and population substructure Forensic Science International, 2005, 148, 47-53

See Also

LRmixTK

Examples

Run this code
#load allele frequencies
library(forensim)
data(ngm)
#create vector of allele frequencies
d10<-ngm$tab$D10
# evaluate the evidence under Hp; contributors are the suspect and one unknown,
# dropout probabilities for the suspect and the unknown are the same: 0.2 for heterozygotes,
# and 0.1 for homozygotes.
likEvid(Repliste=list(c(12,13,14)),T=c(12,13),V=NULL,x=1,theta=0,prDHet=c(0.2,0.2),prDHom=c(0.04,0.04),prC=0,freq=d10)
#  evaluate the evidence under Hd; contributors are two unknown people, the dropout
# probabilities for the unknowns is kept the same under Hd
likEvid(Repliste=list(c(12,13,14)),T=0,V=NULL,x=2,theta=0,prDHet=c(0.2,0.2),prDHom=c(0.04,0.04),prC=0,freq=d10)

Run the code above in your browser using DataLab